@@ -7,6 +7,7 @@
 module GitHub.Endpoints.Activity.Events (
     -- * Events
     repositoryEventsR,
+    userEventsR,
     module GitHub.Data,
     ) where
 
@@ -19,3 +20,9 @@ import Prelude ()
 repositoryEventsR :: Name Owner -> Name Repo -> FetchCount -> Request 'RO (Vector Event)
 repositoryEventsR user repo =
     pagedQuery  ["repos", toPathPart user, toPathPart repo, "events"] []
+
+-- | List user public events.
+-- See <https://developer.github.com/v3/activity/events/#list-public-events-performed-by-a-user>
+userEventsR :: Name User -> FetchCount -> Request 'RO (Vector Event)
+userEventsR user =
+    pagedQuery ["users", toPathPart user, "events", "public"] []
